@@ -92,9 +92,8 @@ class Vault:
         data = self.service.list(filter_expr)
         if len(data) > 0:
             sysout("%YELLOW%{} {}%NC%".format(
-                "\n=== Listing all ({}) vault entries",
-                f"matching \'{filter_expr}\' ===\n" if filter_expr else "===\n",
-                len(data)))
+                f"\n=== Listing all ({len(data)}) vault entries",
+                f"matching \'{filter_expr}\' ===\n" if filter_expr else "===\n"))
             for entry in data:
                 sysout(entry.to_string())
         else:
